@@ -23,6 +23,7 @@ else:
     from .lims2 import SessionInfo
     from . import paths 
 
+logger = logging.getLogger(__name__)
 
 PathLike = Union[str, bytes, os.PathLike, pathlib.Path]
 # https://peps.python.org/pep-0519/#provide-specific-type-hinting-support
@@ -66,11 +67,7 @@ def is_valid_session_id(session_id: int | str) -> bool:
     >>> is_valid_session_id('abcdefg')
     False
     """
-    try:
-        session = lims_data_getter(str(session_id))
-    except:
-        return False
-    return bool(session.data_dict) if hasattr(session, "data_dict") else False
+    return bool(SessionInfo(str(session_id)))
 
 
 def lims_session_id(path: PathLike) -> str | None:
@@ -104,7 +101,7 @@ def folder(path: PathLike) -> str | None:
     if not session_folders:
         return folder_from_lims_id(path)
     if not all(s == session_folders[0] for s in session_folders):
-        logging.warning(
+        logger.warning(
             f"Mismatch between session folder strings - file may be in the wrong folder: {path!r}"
         )
     return session_folders[0]
@@ -159,7 +156,7 @@ def lims_json_content(lims_id: int | str) -> dict | None:
         response = requests.get(f"http://lims2/{session_type}/{lims_id}.json?")
         if response.status_code == 200:
             return response.json()
-    logging.warning(f"Could not find json content for lims session id {lims_id}")
+    logger.warning(f"Could not find json content for lims session id {lims_id}")
     return None
 
 
